@@ -18,9 +18,9 @@ test_that("Fork bombs get mitgated and are properly cleaned up afterwards", {
 	#forkbomb, assuming no more than 300 current procs :-)
 	for(i in 1:5){
 	  Sys.sleep(0.5)
-		expect_that(eval.secure(forkbomb(), RLIMIT_NPROC=300, uid=me), throws_error("unable to fork"))
+		expect_that(eval_safe(forkbomb(), rlimits = list(nproc = 300), uid=me), throws_error("unable to fork"))
 		Sys.sleep(0.5)
-		expect_that(eval.secure(regular(), RLIMIT_NPROC=300, uid=me), is_a("matrix"))
+		expect_that(eval_safe(regular(), rlimits = list(nproc = 300), uid=me), is_a("matrix"))
 		gc();
 	}
 });
@@ -33,9 +33,9 @@ test_that("Raising the limit should not be possible for non-root users", {
 	
 	#run test with several numbers
 	for(mylim in c(400, 200, 300)){
-		output <- list(hardlim = mylim-1, softlim = mylim-1);
-		expect_that(eval.secure(rlimit_nproc(mylim+1), RLIMIT_NPROC = mylim, uid=me), throws_error("privilege"));
-		expect_that(eval.secure(rlimit_nproc(mylim-1), RLIMIT_NPROC = mylim, uid=me), equals(output));
+		output <- list(cur = mylim-1, max = mylim);
+		expect_that(eval_safe(rlimit_nproc(mylim+1), rlimits = list(nproc = mylim), uid=me), throws_error("permi"));
+		expect_that(eval_safe(rlimit_nproc(mylim-1), rlimits = list(nproc = mylim), uid=me), equals(output));
 		rm(output)		
 	}
 });
\ No newline at end of file
